<?php
/**
 * Busybella functions and definitions.
 *
 */

// Exit if accessed directly
if ( ! defined( 'ABSPATH' ) ) {
	exit;
}

/**
 * Theme WP compatibility: 4.5 or later.
 */
if ( version_compare( $GLOBALS['wp_version'], '4.5', '<' ) ) {
	require get_template_directory() . '/includes/back-compatiblity.php';
	return;
}

if ( ! function_exists( 'busybella_theme_setup' ) ) :
/**
 * Theme setup
 */
function busybella_theme_setup() {
	
	// Makes theme available for translation.
	load_theme_textdomain( 'busybella', get_template_directory() . '/languages' );
	
	// Document title
	add_theme_support( 'title-tag' );
	
    // Switches default core markup for below
	add_theme_support( 'html5', array(
		'comment-form',
		'comment-list',
		'gallery',
		'caption',
		'search-form',
	) );

	// This theme supports below mentioned post formats
	add_theme_support( 'post-formats', array(
		'image', 
		'audio', 
		'video', 
		'gallery', 
		'link', 
		'quote', 
	) );

    // Adds thumbnail support
	add_theme_support( 'post-thumbnails' );
	
	// Set the default content width.
	$GLOBALS['content_width'] = 1170;
	
    // Adds RSS feed links to <head> for posts and comments.
	add_theme_support( 'automatic-feed-links' );
	
	// wp_nav_menu() locations
    register_nav_menus( array(
        'primary_menu'		=> 'Primary Menu',
		'sticky_menu'		=> 'Sticky Menu',
    ) );  
	
	// Adds theme support for selective refresh for widgets.
	add_theme_support( 'customize-selective-refresh-widgets' );
	
	// editor style
	add_editor_style( 'assets/css/dtr-editor-style.css' );
	
}
endif; // busybella_theme_setup
add_action( 'after_setup_theme', 'busybella_theme_setup' );

/**
 * Enqueue Plugins Scripts and Styles
 *
 */
if ( ! function_exists( 'busybella_plugin_scripts_styles' ) ) :
function busybella_plugin_scripts_styles() {
	
	// enqueue scripts
	wp_enqueue_script( 'busybella-modernizr-custom', get_template_directory_uri() . '/assets/js/modernizr.custom.js', array('jquery'), '1.0.0', false );
	wp_enqueue_script( 'bootstrap', get_template_directory_uri() . '/assets/js/bootstrap.js', array('jquery'), '3.3.7', true );
	wp_enqueue_script( 'easing', get_template_directory_uri() . '/assets/js/jquery.easing.js', array('jquery'), '1.3.0', true );
	wp_enqueue_script( 'hoverIntent', get_template_directory_uri() . '/assets/js/hoverIntent.js', array('jquery'), '1.0.0', true );
	wp_enqueue_script( 'superfish', get_template_directory_uri() . '/assets/js/superfish.js', array('jquery'), '1.7.6', true );
	wp_enqueue_script( 'select2', get_template_directory_uri() . '/assets/js/select2.js', array('jquery'), '4.0.3', true );
	wp_enqueue_script( 'imagesloaded' );
	wp_enqueue_script( 'masonry' );
	wp_enqueue_script( 'isotope', get_template_directory_uri() . '/assets/js/isotope.js', array('jquery'), '2.2.2', true );
	wp_enqueue_script( 'owl.carousel', get_template_directory_uri() . '/assets/js/owl.carousel.js', array('jquery'), '2.2.1', true );
	wp_enqueue_script( 'fitvids', get_template_directory_uri() . '/assets/js/jquery.fitvids.js', array('jquery'), '1.0.0', true );
	wp_enqueue_script( 'slicknav', get_template_directory_uri() . '/assets/js/jquery.slicknav.js', array('jquery'), '1.0.4', true );
	
	// retina
	if ( true == get_theme_mod( 'busybella_enable_retina_support', false ) ) {
		wp_enqueue_script( 'retina', get_template_directory_uri() . '/assets/js/retina.js', array('jquery'), '1.3.0', true );
	}

	// enqueue styles
	wp_enqueue_style( 'bootstrap', get_template_directory_uri() . '/assets/css/bootstrap.min.css' );
	wp_enqueue_style( 'iconfont', get_template_directory_uri() . '/fonts/iconfont.css' );
	wp_enqueue_style( 'busybella-custom', get_template_directory_uri() . '/assets/css/plugins.css' );
	
	// comments
	if ( is_singular() && comments_open() && get_option( 'thread_comments' ) ) {
		wp_enqueue_script( 'comment-reply' );
	}
	
	// Load the html5 shiv.
	wp_enqueue_script( 'html5', get_theme_file_uri( '/assets/js/html5.js' ), array(), '3.7.3' );
	wp_script_add_data( 'html5', 'conditional', 'lt IE 9' );
	
}
endif; 
add_action( 'wp_enqueue_scripts', 'busybella_plugin_scripts_styles' );
// busybella_plugin_scripts_styles ends

/**
 * Enqueue Custom Scripts and Styles
 *
 */
if ( ! function_exists( 'busybella_custom_scripts_styles' ) ) :
function busybella_custom_scripts_styles() {
	
	// enqueue scripts
	
	wp_enqueue_script( 'busybella-custom-js', get_template_directory_uri() . '/assets/js/custom.js', array('jquery'), '1.0.0', true );
	
	// enqueue main stylesheet and colors
	wp_enqueue_style( 'busybella-style', get_stylesheet_uri() );
	wp_enqueue_style( 'busybella-colors', get_template_directory_uri() . '/assets/css/colors.css' );
	
	if( 'header-v2' == get_theme_mod( 'busybella_header_layout', 'header-v1' ) ) {
		wp_register_style( 'busybella-header-v2', get_template_directory_uri() . '/assets/css/header-v2.css' );
		wp_enqueue_style( 'busybella-header-v2' );
	} 
	
	// register style
	wp_register_style( 'busybella-responsive', get_template_directory_uri() . '/assets/css/responsive.css' );
	if ( true == get_theme_mod( 'busybella_enable_responsive', true ) ) {
		wp_enqueue_style( 'busybella-responsive' );
	}
	
	// RTL support
	if ( is_rtl() ) {
 		wp_enqueue_style( 'busybella-rtl-style', get_template_directory_uri() . '/assets/css/rtl.css' );
	}
}
endif; 
add_action( 'wp_enqueue_scripts', 'busybella_custom_scripts_styles', 20 );
// busybella_custom_scripts_styles ends

/**
 * Enqueue Custom Scripts and Styles Overrides
 *
 */
if ( ! function_exists( 'busybella_custom_scripts_override' ) ) :
function busybella_custom_scripts_override() {
	wp_enqueue_style( 'busybella-custom-override', get_template_directory_uri() . '/assets/css/custom-override.css' );
}
endif; // busybella_custom_scripts_styles
add_action( 'wp_enqueue_scripts', 'busybella_custom_scripts_override', 40 );
// busybella_custom_scripts_override ends

/**
 * Recommend plugins for this theme via TGMPA script
 */
if ( ! function_exists( 'busybella_plugin_setup' ) ) :
function busybella_plugin_setup() {
	require_once( get_template_directory() .'/include-plugins.php' );
}
endif; // busybella_plugin_setup
add_action( 'after_setup_theme', 'busybella_plugin_setup' );

/**
 * Helper Functions
 */
require_once( get_template_directory() .'/includes/helper-functions/pagination.php' );
require_once( get_template_directory() .'/includes/helper-functions/schema-markup.php' );
require_once( get_template_directory() .'/includes/helper-functions/helper-functions.php' );
require_once( get_template_directory() .'/includes/helper-functions/blog-functions.php' );
require_once( get_template_directory() .'/includes/helper-functions/excerpt.php' );

/**
 * Check if the plugin is active and theme can rely on it
 */
function busybella_can_use_plugin( $plugin ) {
	include_once( ABSPATH . 'wp-admin/includes/plugin.php' );
	return is_plugin_active( $plugin );
}

/**
 * Customizer.
 */
require_once( get_template_directory() .'/includes/customizer/include-kirki.php' ); 
require_once( get_template_directory() .'/includes/customizer/kirki-fallback.php' ); 
require_once( get_template_directory() .'/includes/customizer/customizer.php' ); 

/**
 * Body / layout classes
 */
require_once( get_template_directory() .'/includes/body-classes.php' );
require_once( get_template_directory() .'/includes/layout.php' );
require_once( get_template_directory() .'/template-parts/header/page-header.php' );

/**
 * Sidebars / Widgets
 */
require_once( get_template_directory() .'/includes/widgets/sidebars.php' );

/**
 * Register widgets
 */
if( ! function_exists('busybella_register_theme_widgets' ) ) {
	function busybella_register_theme_widgets() {
	  $busybella_theme_widgets = array(
		'about'     	=> 'busybella_about_widget',
	  );
	  foreach ( $busybella_theme_widgets as $key => $value ) {
		require_once( get_template_directory() . '/includes/widgets/' . sanitize_key( $key ) . '.php' );
		register_widget( $value );
	  }
	} 
} // busybella_register_theme_widgets
add_action( 'widgets_init', 'busybella_register_theme_widgets' );

// Custom styles 
require_once ( get_template_directory() . '/includes/custom-styles.php' );

/**
 * Custom callback function for comment display
 */
if( ! function_exists('busybella_comment' ) ) {
	function busybella_comment( $comment, $args, $depth ) {
		$GLOBALS['comment'] = $comment;
		switch ( $comment->comment_type ) :
			case 'pingback' :
			case 'trackback' :
		?>

<li class="post pingback">
	<p> <strong>
		<?php esc_html_e( 'Pingback:', 'busybella' ); ?>
		</strong>
		<?php comment_author_link(); ?>
		<?php edit_comment_link( esc_html__( 'Edit', 'busybella' ), '<span class="edit-link">', '</span>' ); ?>
	</p>
	<?php
				break;
			default :
		?>
<li id="li-comment-<?php comment_ID(); ?>">
	<div id="comment-<?php comment_ID(); ?>" <?php comment_class(); ?>>
		<div class="dtr-comment-author vcard">
			<div class="dtr-comment-author-img">
				<?php if ( 0 != $args['avatar_size'] ) echo get_avatar( $comment, $args['avatar_size']); ?>
			</div>
		</div>
		<div class="dtr-comment-text-wrapper">
			<h6 class="dtr-comment-author"><?php printf( wp_kses( __( '<cite class="fn custom-fn">%s</cite>', 'busybella' ), array( 'a' => array( 'href' => array() ) ) ), get_comment_author_link() ); ?></h6>
			<span class="dtr-comment-metadata"><a href="<?php echo esc_url( get_comment_link( $comment->comment_ID ) ); ?>"><?php printf( esc_html__( '%1$s at %2$s', 'busybella' ), get_comment_date(),  get_comment_time() ); ?> </a>
			<?php edit_comment_link(); ?>
			</span> <span class="dtr-reply">
			<?php comment_reply_link( array_merge( $args, array( 'depth' => $depth, 'max_depth' => $args['max_depth'] ) ) ); ?>
			</span>
			<div class="clearfix"></div>
			<div class="dtr-comment-text">
				<?php comment_text() ?>
			</div>
			<?php if ( '0' == $comment->comment_approved ) : ?>
			<p class="comment-awaiting-moderation">
				<?php esc_html_e( 'Your comment is awaiting moderation.', 'busybella' ) ?>
			</p>
			<?php endif; ?>
		</div>
	</div>
	<?php
		break;
		endswitch;
	}
} // end comment callback function

if ( ! function_exists( 'busybella_embed_allowed_tags' ) ) :
/**
 * Allowed tags for video / audio embed
 */ 
	function busybella_embed_allowed_tags() {	
	$busybella_embed_allowed = array(
	'a' => array(
	'href' => array (),
	'title' => array ()),
	'b' => array(
	'style'=> array(),
	),
	);
	// iframe
	$busybella_embed_allowed['iframe'] = array(
	'src' => array(),
	'height' => array(),
	'width' => array(),
	'frameborder' => array(),
	'allowfullscreen' => array(),
	);
	// video
	$busybella_embed_allowed['video'] = array(
		'width' => true,
		'height' => true
	);
	// source
	$busybella_embed_allowed['source'] = array(
		'src' => true,
		'type' => true
	);
	return $busybella_embed_allowed;
	}
endif;

/**
 * busybella demo data import
 */
function busybella_import_data() {
  return array(
    array(
      'import_file_name'             => 'Busybella Demo Data',
      'local_import_file'            => get_template_directory() . '/includes/imports/content.xml',
      'local_import_widget_file'     => get_template_directory() . '/includes/imports/widgets.wie',
	  'local_import_customizer_file' => get_template_directory() . '/includes/imports/customizer.dat',
      'import_notice'                => wp_kses( __( 'Make sure all the required / recommended plugins are <strong>Installed and Activated.</strong><br><br>Please be patient...click on the Import button only once and wait, <strong>it may take - FEW - minutes.</strong><br><br>After import, error log file may get generated. Nothing to panic, go thorough file. Minor errors like some media / images / sidebar / widget Failed to import, can be ignored. Check if you have posts and pages imported fine.<br><br>Posts, pages, images, widgets, menus and other theme settings will get imported.<br><br>No existing posts, pages, categories, images, custom post types or any other data will be deleted or modified.', 'busybella' ), array( 'strong' => array(), 'br' => array(), 'a' => array( 'href' => array(), 'title' => array(), 'target' => array() ), ) ), // import notice
    ),
  );
}
add_filter( 'pt-ocdi/import_files', 'busybella_import_data' );

// After import
function busybella_after_import_setup() {
	// set menu
    $main_menu		= get_term_by( 'name', 'Primary Menu', 'nav_menu' );
	$footer_menu	= get_term_by( 'name', 'Copyright Menu', 'nav_menu' );
    set_theme_mod( 'nav_menu_locations', array(
            'primary_menu'		=> $main_menu->term_id,
			'sticky_menu' 		=> $main_menu->term_id,
			'copyright_menu'	=> $footer_menu->term_id,
        )
    );
	// set home and blog page
	$front_page_id = get_page_by_title( 'Home' );
    $blog_page_id  = get_page_by_title( 'Blog' );
    update_option( 'show_on_front', 'page' );
    update_option( 'page_on_front', $front_page_id->ID );
    update_option( 'page_for_posts', $blog_page_id->ID );
}
add_action( 'pt-ocdi/after_import', 'busybella_after_import_setup' );

// Custom Header
function busybella_plugin_page_setup( $default_settings ) {
    $default_settings['parent_slug'] = 'themes.php';
    $default_settings['page_title']  = esc_html__( 'Busybella Demo Import' , 'busybella' );
    $default_settings['menu_title']  = esc_html__( 'Import Theme Demo Data' , 'busybella' );
    $default_settings['capability']  = 'import';
    $default_settings['menu_slug']   = 'pt-one-click-demo-import';

    return $default_settings;
}
add_filter( 'pt-ocdi/plugin_page_setup', 'busybella_plugin_page_setup' );

// Branding
add_filter( 'pt-ocdi/disable_pt_branding', '__return_true' );

// Import only original size images
add_filter( 'pt-ocdi/regenerate_thumbnails_in_content_import', '__return_false' );

/**
 *  Add custom image sizes attribute to WP native responsive image functionality
 */
if ( ! function_exists( 'busybella_calculate_image_sizes' ) ) :
	function busybella_calculate_image_sizes( $sizes, $size ) {
		
		$width = $size[0];

		// blog		
		if ( is_home() || is_archive() ) {
			if (  'dtr-blog-default' == get_theme_mod( 'busybella_blog_entry_style', 'dtr-blog-default' ) ) {
				if (  'dtr-fullwidth' == get_theme_mod( 'busybella_blog_layout', 'dtr-right-sidebar' )  ) {
					$sizes = '(max-width: 768px) 92vw, (max-width: 992px) 780px, (max-width: 1071px) 980px, 1170px'; 
				} else {
					$sizes  = '(max-width: 768px) 92vw, (max-width: 992px) 820px, (max-width: 1024px) 690px, (max-width: 1071px) 690px, 980px';
				}
			} else {
				$sizes  = '(max-width: 768px) 92vw, (max-width: 992px) 690px, 690px';
			}
		}

		// single
		if ( is_single() ) {
			if (  'dtr-fullwidth' == get_theme_mod( 'busybella_single_post_layout', 'dtr-fullwidth' ) && '' == get_post_meta( get_the_ID(), '_busybella_page_layout_meta', true ) ||  'dtr-fullwidth' == get_theme_mod( 'busybella_single_post_layout', 'dtr-fullwidth' ) && 'dtr-fullwidth' == get_post_meta( get_the_ID(), '_busybella_page_layout_meta', true ) || 'dtr-fullwidth' == get_post_meta( get_the_ID(), '_busybella_page_layout_meta', true ) ) {
				$sizes = '(max-width: 768px) 92vw, (max-width: 992px) 780px, (max-width: 1071px) 980px, 1170px'; 
			} else {
				$sizes = '(max-width: 768px) 92vw, (max-width: 992px) 820px, (max-width: 1024px) 690px, (max-width: 1071px) 690px, 980px';	
			}
		}		

		// page
		if ( is_page() ) {
			if (  'dtr-fullwidth' == get_theme_mod( 'busybella_page_layout', 'dtr-fullwidth' ) && '' == get_post_meta( get_the_ID(), '_busybella_page_layout_meta', true ) ||  'dtr-fullwidth' == get_theme_mod( 'busybella_single_post_layout', 'dtr-fullwidth' ) && 'dtr-fullwidth' == get_post_meta( get_the_ID(), '_busybella_page_layout_meta', true ) || 'dtr-fullwidth' == get_post_meta( get_the_ID(), '_busybella_page_layout_meta', true ) ) {
				$sizes = '(max-width: 768px) 92vw, (max-width: 992px) 780px, (max-width: 1071px) 980px, 1170px'; 
			} else {
				$sizes = '(max-width: 768px) 92vw, (max-width: 992px) 820px, (max-width: 1024px) 690px, (max-width: 1071px) 690px, 980px';	
			}
		}		
		
		// small sizes
		if ($width < 690 ) {
        	$sizes = '(max-width: 768px) 92vw, (max-width: 992px) 690px, 690px';
        }

		// return
		return $sizes;
	}
	add_filter('wp_calculate_image_sizes', 'busybella_calculate_image_sizes', 10 , 2);
endif;

/**
 * WooCommerce
 *
 */
// Check if WooCommerce is activated
if ( ! function_exists( 'busybella_is_woocommerce_activated' ) ) {
	function busybella_is_woocommerce_activated() {
		if ( class_exists( 'woocommerce' ) ) { return true; } else { return false; }
	}
} // busybella_is_woocommerce_activated

// WooCommerce functions
if( busybella_is_woocommerce_activated() ) {
	require_once( get_template_directory() . '/includes/woocommerce/woocommerce.php' );
	require_once( get_template_directory() . '/includes/woocommerce/woo-social-share.php' );
	require_once( get_template_directory() . '/includes/woocommerce/woo-layout.php' );
	add_theme_support( 'wc-product-gallery-lightbox' );
	add_theme_support( 'wc-product-gallery-slider' );
}

// Enqueue Scripts and Styles for WooCommerce if installed
if( ! function_exists('busybella_woocommerce_scripts_styles' ) ) {
	function busybella_woocommerce_scripts_styles() {
		if( busybella_is_woocommerce_activated() ) {
			wp_enqueue_style( 'woocommerce-style',  get_template_directory_uri() . '/assets/css/woocommerce.css' );
		}	
	}
	add_action( 'wp_enqueue_scripts', 'busybella_woocommerce_scripts_styles' );
} // busybella_woocommerce_scripts_styles

// Cart item numbers update
add_filter( 'woocommerce_add_to_cart_fragments', 'busybella_woocommerce_add_to_cart' );
function busybella_woocommerce_add_to_cart( $fragments ) {
	ob_start();
	?>
	<div class="cart-items-wrapper"><a href="<?php echo  WC()->cart->get_cart_url(); ?>" title="<?php esc_html_e('View your shopping cart', 'busybella'); ?>"><div class="cart-items"><?php echo sprintf(_n('<span class="item-number">%d</span>', '<span class="item-number">%d</span>',  WC()->cart->cart_contents_count, 'busybella'),  WC()->cart->cart_contents_count);?></div></a></div>
	<?php
	$fragments['div.cart-items-wrapper'] = ob_get_clean();
    return $fragments;
}