<?php
/**
 * Theme schema markup
 */

/**
 * Schema markup output
 */
if ( ! function_exists( 'busybella_schema_markup' ) ) :
function busybella_schema_markup( $schema_location ) {
	echo busybella_return_schema_markup( $schema_location );
}
endif; // busybella_schema_markup

/**
 * Build schema markup
 * $schemamarkup = 'itemscope="itemscope" itemprop=" ' . $itemprop . '" itemtype="' . $itemtype . '"';
 */
if ( ! function_exists( 'busybella_return_schema_markup' ) ) :
function busybella_return_schema_markup( $schema_location ) {

	//Return if schema disabled
	if ( ! get_theme_mod( 'busybella_enable_schema_markup', true ) ) {
		return null;
	}

	//Define Variables
	$schemamarkup = $itemscope = $itemprop = $itemtype = '';
	$itemscope = 'itemscope="itemscope"';

	// Schema Location
	if ( 'html' == $schema_location ) {
		if ( is_singular() ) {
			$schemamarkup = ' ' . $itemscope . ' itemtype="http://schema.org/WebPage"';
		} else {
			$schemamarkup = ' ' . $itemscope . ' itemtype="http://schema.org/Article"';
		}
	} elseif ( 'body' == $schema_location ) {
		if ( is_singular( 'post' ) ) {
			// $itemtype = "Article";
		} elseif ( is_search() ) {
			$itemtype = 'SearchResultsPage';
		} elseif ( is_author() ) {
			$itemtype = 'AuthorProfilePage';
		}
		if ( $itemtype ) {
			$schemamarkup = ' ' . $itemscope . ' itemtype="'. $itemtype .'"';
		}
	} elseif ( 'header' == $schema_location ) {
		$schemamarkup = ' ' . $itemscope . ' itemtype="http://schema.org/WPHeader"';
	} elseif ( 'site_navigation' == $schema_location ) {
		$schemamarkup = ' ' . $itemscope . ' itemtype="http://schema.org/SiteNavigationElement"';
	} elseif ( 'main' == $schema_location ) {
		$itemtype = 'http://schema.org/WebPageElement';
		$itemprop = 'mainContentOfPage';
		if ( is_singular( 'post' ) ) {
			$itemprop = '';
			$itemtype = 'http://schema.org/Blog';
		}
		// $schemamarkup = ' ' . $itemscope . ' itemtype="'. $itemtype .'"';
	} elseif ( 'sidebar' == $schema_location ) {
		$schemamarkup = ' ' . $itemscope . ' itemtype="http://schema.org/WPSideBar"';
	} elseif ( 'footer' == $schema_location ) {
		$schemamarkup = ' ' . $itemscope . ' itemtype="http://schema.org/WPFooter"';
	} elseif ( 'headline' == $schema_location ) {
		$schemamarkup = 'itemprop="headline"';
	} elseif ( 'image' == $schema_location ) {
		$schemamarkup = 'itemprop="image"';
	} elseif ( 'entry_content' == $schema_location ) {
		$schemamarkup = 'itemprop="text"';
	} elseif ( 'publish_date' == $schema_location ) {
		$schemamarkup = 'itemprop="datePublished"';
	} elseif ( 'author_name' == $schema_location ) {
		$schemamarkup = 'itemprop="name"';
	} elseif ( 'author_link' == $schema_location ) {
		$schemamarkup = 'itemprop="author" ' . $itemscope . ' itemtype="http://schema.org/Person"';
	} elseif ( 'blog_post' == $schema_location ) {
		// $schemamarkup = ' ' . $itemscope . ' itemprop="blogPost" itemtype="http://schema.org/BlogPosting"';
	}
	// return schema markup
	return $schemamarkup;
}
endif; // busybella_return_schema_markup