<?php
/**
 * Fetch Instagram feed
 */
 
// Exit if accessed directly
if ( ! defined( 'ABSPATH' ) ) {
	exit;
} 
if( ! function_exists('busybella_scrape_instagram' ) ) { 
	function busybella_scrape_instagram( $username , $item_count = 4 ) {
		
		// username
		$username = strtolower( $username );
		$sanitized_username = str_replace( '@', '', $username );
		
		if ( false === ( $instagram = get_transient( 'busybella-instagram-feed-'. $sanitized_username .'-'. $item_count ) ) ) {

			$remote = wp_remote_get( 'http://instagram.com/'. trim( $username ) );
			
			if ( is_wp_error( $remote ) )
			return new WP_Error( 'site_down', esc_html__( 'Unable to communicate with Instagram.', 'busybella' ) );

			if ( 200 != wp_remote_retrieve_response_code( $remote ) )
			return new WP_Error( 'invalid_response', esc_html__( 'Instagram did not return a 200.', 'busybella' ) );
			
			$shards = explode( 'window._sharedData = ', $remote['body'] );
			$insta_json = explode( ';</script>', $shards[1] );
			$insta_array = json_decode( $insta_json[0], TRUE );

			if ( ! $insta_array )
			return new WP_Error( 'bad_json', esc_html__( 'Instagram has returned invalid data.', 'busybella' ) );

			if ( isset( $insta_array['entry_data']['ProfilePage'][0]['user']['media']['nodes'] ) ) {
				$images = $insta_array['entry_data']['ProfilePage'][0]['user']['media']['nodes'];
			} else {
				return new WP_Error( 'bad_json_2', esc_html__( 'Instagram has returned invalid data.', 'busybella' ) );
			}
			
			if ( ! is_array( $images ) )
			return new WP_Error( 'bad_array', esc_html__( 'Instagram has returned invalid data.', 'busybella' ) );

			$instagram = array();

			foreach ( $images as $image ) {

				$image['thumbnail_src'] = preg_replace( '/^https?\:/i', '', $image['thumbnail_src'] );
				$image['display_src'] = preg_replace( '/^https?\:/i', '', $image['display_src'] );

				$image['thumbnail_src'] = preg_replace( '/^https?\:/i', '', $image['thumbnail_src'] );
				$image['display_src'] = preg_replace( '/^https?\:/i', '', $image['display_src'] );

				// handle both types of CDN url
				if ( (strpos( $image['thumbnail_src'], 's640x640' ) !== false ) ) {
					$image['thumbnail'] = str_replace( 's640x640', 's160x160', $image['thumbnail_src'] );
					$image['small'] = str_replace( 's640x640', 's320x320', $image['thumbnail_src'] );
				} else {
					$urlparts = wp_parse_url( $image['thumbnail_src'] );
					$pathparts = explode( '/', $urlparts['path'] );
					array_splice( $pathparts, 3, 0, array( 's160x160' ) );
					$image['thumbnail'] = '//' . $urlparts['host'] . implode('/', $pathparts);
					$pathparts[3] = 's320x320';
					$image['small'] = '//' . $urlparts['host'] . implode('/', $pathparts);
				}

				$image['large'] = $image['thumbnail_src'];

				if ( $image['is_video'] == true ) {
					$type = 'video';
				} else {
					$type = 'image';
				}

				$instagram[] = array(
					'description'   => esc_html__( 'Instagram Image', 'busybella' ),
					'link'		    => '//instagram.com/p/' . $image['code'],
					'time'		    => $image['date'],
					'comments'	    => $image['comments']['count'],
					'likes'		    => $image['likes']['count'],
					'thumbnail_src' => isset( $image['thumbnail_src'] ) ? $image['thumbnail_src'] : '',
					'display_src'   => $image['display_src'],
					'thumbnail'	 	=> $image['thumbnail'],
					'small'         => $image['small'],
					'large'         => $image['large'],
					'original'      => $image['display_src'],
					'type'          => $type,
				);

			}

			// do not set an empty transient - should help catch private or empty accounts
			if ( ! empty( $instagram ) ) {
				$instagram = serialize( $instagram );
				set_transient( 'busybella-instagram-feed-'.sanitize_title_with_dashes( $username ), $instagram, apply_filters( 'busybella_instagram_cache_time', HOUR_IN_SECONDS*2 ) );
			}

		}
		// Return array
		if ( ! empty( $instagram )  ) {
			if ( ! is_array( $instagram ) && 1 != $instagram ) {
				$instagram = unserialize( $instagram );
			}
			if ( is_array( $instagram ) ) {
				return array_slice( $instagram, 0, $item_count );
			}
		}
		// No images returned
		else {
			return new WP_Error( 'no_images', esc_html__( 'Instagram did not return any images.', 'busybella' ) );
		}
	}
} //busybella_scrape_instagram