<?php
/**
 * Recent Posts Widget
 */

// Exit if accessed directly
if ( ! defined( 'ABSPATH' ) ) {
	exit;
}
// class starts
if ( ! class_exists( 'BUSYBELLA_Recentposts_Widget' ) ) {
	class BUSYBELLA_Recentposts_Widget extends WP_Widget {
	
		private $defaults;
		
		/**
		 * Register widget
		 */
		public function __construct() {
			
			// Defaults
			$this->defaults = array(
				'title'         => '',
				'number'        => '3',
				'post_type'     => 'post',
				'order'         => 'DESC',
				'orderby'       => 'date',
				'date'          => '',
				'thumb'         => '',
				'excerpt'       => '',
			);
		
			$widget_ops = array(
      			'classname' => 'busybella_recentposts_widget',
      			'description' => esc_html__( 'Display Recent Posts.', 'busybella' ),
    		);
    		parent::__construct( 'busybella_recentposts_widget', esc_html__( 'Custom: Recent Posts', 'busybella' ), $widget_ops );
		}
		
		/**
	 	 * Output the content of the widget
		 */
		public function widget( $args, $instance ) {

			extract( wp_parse_args( $instance, $this->defaults ) );

			// vars
			$output = '';
			$title = isset( $instance['title'] ) ? apply_filters( 'widget_title', $instance['title'] ) : '';
		
			// Before widget
			$output .= $args['before_widget'];

			// Query posts
			$query_args = array(
				'post_type' 			=> 'post',
				'posts_per_page' 		=> $number,
				'no_found_rows'  		=> true,
				'post_status' 			=> 'publish', 
				'ignore_sticky_posts'	=> true,
			);
			
			// Current post exclude
			if ( is_singular() ) {
				$query_args['post__not_in'] = array( get_the_ID() );
			}
			
			// Order / orderby
			if ( ! empty( $orderby ) ) {
				$query_args['order']   = $order;
				$query_args['orderby'] = $orderby;
			} else {
				$query_args['orderby'] = $order; // fallback
			}

			// Query posts
			$dtr_query = new WP_Query( $query_args );
			if ( $dtr_query->have_posts()) : 
			// Widget title
			if ( $title ) {
				$output .= $args['before_title'];
					$output .= $title;
				$output .= $args['after_title'];
			}

$output .= '<div class="dtr-recent-entries-widget clearfix"><ul class="dtr-recent-entries">';
 while ( $dtr_query->have_posts() ) : $dtr_query->the_post();
	$output .= '<li>';
	if ( 'on' != $thumb && has_post_thumbnail() ) {
		$output .= '<div class="dtr-recent-entries-thumb">';
		$output .= get_the_post_thumbnail(get_the_ID(), 'thumbnail'); 
		$output .= '</div>';
	}
	$output .= '<div class="dtr-recent-entries-info">';
	$output .= '<h6 class="dtr-recent-entry-title"><a href="' . esc_url ( get_the_permalink() ) . '" title="'. esc_attr ( get_the_title() ) .'">';
    $output .= get_the_title();
    $output .= '</a></h6>';
	// date
	if ( 'on' != $date ) {
		$output .= '<span class="dtr-recent-entries-date dtr-meta-style">' .  get_the_date() . '</span>';
	}
	// excerpt
	if ( 'on' != $excerpt ) {
		$output .= '<div class="dtr-recent-entries-excerpt">';
			$content =  wp_trim_words( get_the_excerpt(), 12, '...' );
			$content = preg_replace( '/\[[^\]]+\]/', '', $content );
			$output .= $content;
		$output .= '</div>';						
	}
	$output .= '</div>';
	$output .= '</li>';
	endwhile; 
$output .= '</ul></div>';

 wp_reset_postdata();
			endif;
			// output ends

			// After widget
			$output .= $args['after_widget'];

			// output echo
			echo $output;
		
		} 

		/**
		 *  Update the information in the WordPress database
		 */	
		 
		public function update( $new_instance, $old_instance ) {
			$instance               = $old_instance;
			$instance['title']      = ( ! empty( $new_instance['title'] ) ) ? strip_tags( $new_instance['title'] ) : '';
			$instance['number'] 	= ! empty( $new_instance['number'] ) ? strip_tags( $new_instance['number'] ) : '';
			$instance['order'] 		= ! empty( $new_instance['order'] ) ? strip_tags( $new_instance['order'] ) : '';
			$instance['orderby']	= ! empty( $new_instance['orderby'] ) ? strip_tags( $new_instance['orderby'] ) : '';
			$instance['date']		= isset( $new_instance['date'] ) ? true : false;
			$instance['thumb'] 		= isset( $new_instance['thumb'] ) ? true : false;
			$instance['excerpt'] 	= isset( $new_instance['excerpt'] ) ? true : false;
			return $instance;
		} 

		/**
		 * Add form fields to the widget which will be displayed in the WordPress admin area.
		 */
		public function form( $instance ) {
			extract( wp_parse_args( ( array ) $instance, $this->defaults ) ); ?>
<p>
	<label for="<?php echo esc_attr( $this->get_field_id( 'title' ) ); ?>">
		<?php esc_attr_e( 'Title', 'busybella' ); ?>
	</label>
	<input class="widefat" name="<?php echo esc_attr( $this->get_field_name( 'title' ) ); ?>" type="text" value="<?php echo esc_attr( $title ); ?>" />
</p>
<p>
	<label for="<?php echo esc_attr( $this->get_field_id( 'order' ) ); ?>">
		<?php esc_html_e( 'Order', 'busybella' ); ?>
	</label>
	<br />
	<select name="<?php echo esc_attr( $this->get_field_name( 'order' ) ); ?>">
		<option value="DESC" <?php selected( $order, 'DESC', true ); ?>>
		<?php esc_html_e( 'Descending', 'busybella' ); ?>
		</option>
		<option value="ASC" <?php selected( $order, 'ASC', true ); ?>>
		<?php esc_html_e( 'Ascending', 'busybella' ); ?>
		</option>
	</select>
</p>
<p>
	<label for="<?php echo esc_attr( $this->get_field_id( 'orderby' ) ); ?>">
		<?php esc_html_e( 'Order By', 'busybella' ); ?>
		:</label>
	<br />
	<select name="<?php echo esc_attr( $this->get_field_name( 'orderby' ) ); ?>" id="<?php echo esc_attr( $this->get_field_id( 'orderby' ) ); ?>">
		<?php
			// Orderby options
			$orderby_array = array (
				'date'          => esc_html__( 'Date', 'busybella' ),
				'title'         => esc_html__( 'Title', 'busybella' ),
				'rand'          => esc_html__( 'Random', 'busybella' ),
				'author'        => esc_html__( 'Author', 'busybella' ),
				'comment_count' => esc_html__( 'Comment Count', 'busybella' ),
			);
			foreach ( $orderby_array as $key => $value ) { ?>
		<option value="<?php echo esc_attr( $key ); ?>" <?php selected( $orderby, $key ); ?>> <?php echo strip_tags( $value ); ?> </option>
		<?php } ?>
	</select>
</p>
<p>
	<label for="<?php echo esc_attr( $this->get_field_id( 'number' ) ); ?>">
		<?php esc_html_e( 'Number', 'busybella' ); ?>
	</label>
	<input class="widefat" name="<?php echo esc_attr( $this->get_field_name( 'number' ) ); ?>" type="text" value="<?php echo esc_attr( $number ); ?>" />
</p>
<p>
	<input name="<?php echo esc_attr( $this->get_field_name( 'date' ) ); ?>" type="checkbox" value="1" <?php checked( $date, '1', true ); ?> />
	<label for="<?php echo esc_attr( $this->get_field_id( 'date' ) ); ?>">
		<?php esc_html_e( 'Disable Date?', 'busybella' ); ?>
	</label>
</p>
<p>
	<input name="<?php echo esc_attr( $this->get_field_name( 'thumb' ) ); ?>" type="checkbox" value="1" <?php checked( $thumb, '1', true ); ?> />
	<label for="<?php echo esc_attr( $this->get_field_id( 'thumb' ) ); ?>">
		<?php esc_html_e( 'Disable Image?', 'busybella' ); ?>
	</label>
</p>
<p>
	<input name="<?php echo esc_attr( $this->get_field_name( 'excerpt' ) ); ?>" type="checkbox" value="1" <?php checked( $excerpt, '1', true ); ?> />
	<label for="<?php echo esc_attr( $this->get_field_id( 'excerpt' ) ); ?>">
		<?php esc_html_e( 'Disable Excerpt?', 'busybella' ); ?>
	</label>
</p>
<?php
		} 
	// class ends
	}
}
register_widget( 'BUSYBELLA_Recentposts_Widget' );