<?php
namespace BusybellaAddons;
use BusybellaAddons\Widgets\Busybella_Promobox;
use BusybellaAddons\Widgets\Busybella_Packagebox;
use BusybellaAddons\Widgets\Busybella_About;
use BusybellaAddons\Widgets\Busybella_Testimonial_Carousel;
use BusybellaAddons\Widgets\Busybella_Testimonial_Single;
use BusybellaAddons\Widgets\Busybella_Praise;
use BusybellaAddons\Widgets\Busybella_Recentposts_Carousel;
use BusybellaAddons\Widgets\Busybella_Button;
use BusybellaAddons\Widgets\Busybella_Quote;

if ( ! defined( 'ABSPATH' ) ) exit; // Exit if accessed directly
/**
 * Main Plugin Class
 * Register new elementor widget.
 * @since 1.0.0
 */
class Busybella_Elementor_Addons {
	/**
	 * Constructor
	 * @since 1.0.0
	 * @access public
	 */
	public function __construct() {
		$this->add_actions();
	}
	
	/**
	 * Add Actions
	 * @since 1.0.0
	 * @access private
	 */
	private function add_actions() {
		add_action( 'elementor/widgets/widgets_registered', [ $this, 'on_widgets_registered' ] );
		add_action( 'elementor/init', array( $this, 'add_elementor_category' ) );
	}
	
	/**
	 * On Widgets Registered
	 * @since 1.0.0
	 * @access public
	 */
	public function on_widgets_registered() {
		$this->includes();
		$this->register_widget();
	}
	
	/**
	 * Add Category
	 * @since 1.0.0
	 * @access public
	 */
	 public function add_elementor_category() {
		\Elementor\Plugin::instance()->elements_manager->add_category(
			'dtr-element',
			array(
				'title' => __('Busybella Addons', 'busybella'),
				'icon' => 'fa fa-plug',
			),
			1);
      }

	/**
	 * Includes
	 * @since 1.0.0
	 * @access private
	 */
	private function includes() {
		require __DIR__ . '/widgets/dtr-button.php';
		require __DIR__ . '/widgets/dtr-promobox.php';
		require __DIR__ . '/widgets/dtr-packagebox.php';
		require __DIR__ . '/widgets/dtr-about.php';
		require __DIR__ . '/widgets/dtr-testimonial-carousel.php';
		require __DIR__ . '/widgets/dtr-testimonial-single.php';
		require __DIR__ . '/widgets/dtr-praise.php';
		require __DIR__ . '/widgets/dtr-recentposts-carousel.php';
		require __DIR__ . '/widgets/dtr-quote.php';
	}
	
	/**
	 * Register Widget
	 * @since 1.0.0
	 * @access private
	 */
	private function register_widget() {
		\Elementor\Plugin::instance()->widgets_manager->register_widget_type( new Busybella_Button() );
		\Elementor\Plugin::instance()->widgets_manager->register_widget_type( new Busybella_Promobox() );
		\Elementor\Plugin::instance()->widgets_manager->register_widget_type( new Busybella_Packagebox() );
		\Elementor\Plugin::instance()->widgets_manager->register_widget_type( new Busybella_About() );
		\Elementor\Plugin::instance()->widgets_manager->register_widget_type( new Busybella_Testimonial_Carousel() );
		\Elementor\Plugin::instance()->widgets_manager->register_widget_type( new Busybella_Testimonial_Single() );
		\Elementor\Plugin::instance()->widgets_manager->register_widget_type( new Busybella_Praise() );
		\Elementor\Plugin::instance()->widgets_manager->register_widget_type( new Busybella_Recentposts_Carousel() );
		\Elementor\Plugin::instance()->widgets_manager->register_widget_type( new Busybella_Quote() );
	}
}
new Busybella_Elementor_Addons();