<?php
namespace BusybellaAddons\Widgets;

use Elementor\Widget_Base;
use Elementor\Controls_Manager;
use Elementor\Utils;
use Elementor\Control_Media;

if ( ! defined( 'ABSPATH' ) ) {
	exit; // Exit if accessed directly.
}

/**
 * Promobox Widget
 */
class Busybella_Promobox extends Widget_Base {

	/**
	 * Retrieve widget name.
	 * @access public
	 * @return string Widget name.
	 */
	public function get_name() {
		return 'promobox';
	}

	/**
	 * Retrieve widget title.
	 * @access public
	 * @return string Widget title.
	 */
	public function get_title() {
		return __( 'Promobox', 'busybella' );
	}

	/**
	 * Retrieve widget icon.
	 * @access public
	 * @return string Widget icon.
	 */
	public function get_icon() {
		return 'eicon-favorite';
	}

	/**
	 * Retrieve the list of categories widget belongs to.
	 * Used to determine where to display the widget in the editor.
	 * @access public
	 * @return array Widget categories.
	 */
	public function get_categories() {
		  return array('dtr-element');

	}

	/**
	 * Register widget controls.
	 * Adds different input fields to allow the user to change and customize the widget settings.
	 * @access protected
	 */
	protected function _register_controls() {
		
		// image control starts
		$this->start_controls_section(
			'section_promobox_image',
			[
				'label' => __( 'Promobox Background', 'busybella' ),
			]
		);
		
		$this->add_control(
			'promobox_bg_image',
			[
				'label' => __( 'Background Image', 'busybella' ),
				'type' => Controls_Manager::MEDIA,
					'selectors' => [
				'{{WRAPPER}} div.dtr-promobox-wrapper, {{WRAPPER}} .dtr-promobox-wrapper' => 'background-image: url("{{URL}}");',
			],
			
			]
		);
		
		$this->add_control(
			'promobox_bg_image_position',
			[
				'label' => __( 'Background Position', 'busybella' ),
				'type' => Controls_Manager::SELECT,
				'default' => '',
				'options' => [
					'' => _x( 'Default', 'Background Control', 'busybella' ),
				'top left' => _x( 'Top Left', 'Background Control', 'busybella' ),
				'top center' => _x( 'Top Center', 'Background Control', 'busybella' ),
				'top right' => _x( 'Top Right', 'Background Control', 'busybella' ),
				'center left' => _x( 'Center Left', 'Background Control', 'busybella' ),
				'center center' => _x( 'Center Center', 'Background Control', 'busybella' ),
				'center right' => _x( 'Center Right', 'Background Control', 'busybella' ),
				'bottom left' => _x( 'Bottom Left', 'Background Control', 'busybella' ),
				'bottom center' => _x( 'Bottom Center', 'Background Control', 'busybella' ),
				'bottom right' => _x( 'Bottom Right', 'Background Control', 'busybella' ),
				],
				'selectors' => [
				'{{WRAPPER}} div.dtr-promobox-wrapper, {{WRAPPER}} .dtr-promobox-wrapper' => 'background-position: {{VALUE}};',
				],
			]
		);
		
		$this->add_control(
			'promobox_bg_image_repeat',
			[
				'label' => __( 'Background Repeat', 'busybella' ),
				'type' => Controls_Manager::SELECT,
				'default' => '',
				'options' => [
					'' => _x( 'Default', 'Background Control', 'busybella' ),
				'no-repeat' => _x( 'No-repeat', 'Background Control', 'busybella' ),
				'repeat' => _x( 'Repeat', 'Background Control', 'busybella' ),
				'repeat-x' => _x( 'Repeat-x', 'Background Control', 'busybella' ),
				'repeat-y' => _x( 'Repeat-y', 'Background Control', 'busybella' ),
				],
				'selectors' => [
				'{{WRAPPER}} div.dtr-promobox-wrapper, {{WRAPPER}} .dtr-promobox-wrapper' => 'background-repeat: {{VALUE}};',
				],
			]
		);
		
		$this->add_control(
			'promobox_bg_image_size',
			[
				'label' => __( 'Background Repeat', 'busybella' ),
				'type' => Controls_Manager::SELECT,
				'default' => '',
				'options' => [
					'' => _x( 'Default', 'Background Control', 'busybella' ),
				'auto' => _x( 'Auto', 'Background Control', 'busybella' ),
				'cover' => _x( 'Cover', 'Background Control', 'busybella' ),
				'contain' => _x( 'Contain', 'Background Control', 'busybella' ),
				],
				'selectors' => [
				'{{WRAPPER}} div.dtr-promobox-wrapper, {{WRAPPER}} .dtr-promobox-wrapper' => 'background-size: {{VALUE}};',
				],
			]
		);
		
		$this->end_controls_section();
		// image control ends
		
		// content control starts
		$this->start_controls_section(
			'section_promobox',
			[
				'label' => __( 'Promobox Content', 'busybella' ),
			]
		);

		// title
		$this->add_control(
			'promobox_title',
			[
				'label' => __( 'Title', 'busybella' ),
				'type' => Controls_Manager::TEXT,
				'default' => __( 'This is the heading', 'busybella' ),
				'placeholder' => __( 'Your Title', 'busybella' ),
				'label_block' => true,
			]
		);
	
		// content
		$this->add_control(
			'promobox_text',
			[
				'name' => 'tab_content',
				'label' => __( 'Text On Hover', 'busybella' ),
				'type' => Controls_Manager::WYSIWYG,
				'default' => __( 'Your On Hover Text', 'busybella' ),
				'show_label' => true,
			]
		);
		
		$this->add_control(
			'promobox_btn_link',
			[
				'label' => __( 'Link to Promobox', 'busybella' ),
				'type' => Controls_Manager::URL,
				'placeholder' => 'http://your-link.com',
				'description' => __('Leave blank if link not required', 'busybella'),
				'default' => [
					'url' => '',
				],
			]
		);
		
		$this->add_control(
			'view',
			[
				'label' => __( 'View', 'busybella' ),
				'type' => Controls_Manager::HIDDEN,
				'default' => 'traditional',
			]
		);
		$this->end_controls_section();
		// content control ends
		
		// style control starts
		$this->start_controls_section(
			'section_style_content',
			[
				'label' => __( 'Caption', 'busybella' ),
				'tab'   => Controls_Manager::TAB_STYLE,
			]
		);
		
		$this->add_control(
			'promobox_caption_bg',
			[
				'label' => __( 'Caption Background Color', 'busybella' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .dtr-promobox-caption, {{WRAPPER}} .dtr-promobox-caption' => 'background-color: {{VALUE}};',
				],
			]
		);
		
		$this->add_control(
			'promobox_title_color',
			[
				'label' => __( 'Color', 'busybella' ),
				'type' => Controls_Manager::COLOR,
				'default' => '',
				'selectors' => [
					'{{WRAPPER}} .dtr-promobox-caption-title' => 'color: {{VALUE}};',
				],
			]
		);
		
		$this->add_control(
			'promobox_text_color',
			[
				'label' => __( 'Color', 'busybella' ),
				'type' => Controls_Manager::COLOR,
				'default' => '',
				'selectors' => [
					'{{WRAPPER}} .dtr-promobox-caption-text' => 'color: {{VALUE}};',
				],
			]
		);
		
		$this->end_controls_section();
		// style control ends
	}

	/**
	 * Render widget output on the frontend.
	 * Written in PHP and used to generate the final HTML.
	 * @access protected
	 */
	protected function render() {
		$settings = $this->get_settings();
		$html = '';
		$html .= '<div class="dtr-promobox-wrapper dtr-promobox-caption-js-hover">';
			$html .= '<div class="dtr-promobox">';
				$html .= '<div class="dtr-promobox-caption">';
		
					if ( ! empty( $settings['promobox_title'] ) ) {
						$html .= sprintf( '<h5 class="dtr-promobox-caption-title">%s</h5>', $settings['promobox_title'] );
					}
		
					if ( ! empty( $settings['promobox_text'] ) ) {
						$html .= sprintf( '<div class="dtr-promobox-caption-text dtr-promobox-caption-text-on-hover">%s</div>', $settings['promobox_text'] );
					}
		
				$html .= '</div>';
		
				if ( ! empty( $settings['promobox_btn_link']['url'] ) ) {
					if ( ! empty( $settings['promobox_btn_link']['url'] ) ) {
						$link = esc_url( $settings['promobox_btn_link']['url'] );
					} 
					$target = $settings['promobox_btn_link']['is_external'] ? 'target="_blank"' : '';
					$nofollow = $settings['promobox_btn_link']['nofollow'] ? 'rel="nofollow"' : '';
					$html .= sprintf( '<a class="dtr-promobox-link-wrap" href="%1$s" %2$s %3$s></a>', $link, $target, $nofollow );
				}
	
			$html .= '</div>';
		$html .= '</div>';
		echo $html;
	}

	/**
	 * Render widget output in the editor.
	 * Written as a Backbone JavaScript template and used to generate the live preview.
	 * @access protected
	 */
	protected function _content_template() {
		?>
		<#
	
		var html = '<div class="dtr-promobox-wrapper"><div class="dtr-promobox dtr-promobox-caption-js-hover">';
		var hasContent = !! ( settings.promobox_title );
		if ( hasContent ) {
			html += '<div class="dtr-promobox-caption">';
				
				if ( settings.promobox_title ) {
					var title_html = settings.promobox_title;
					html += '<h5 class="dtr-promobox-caption-title">' + title_html + '</h5>';
				}
				
				if ( settings.promobox_text ) {
					html += '<div class="promobox-caption-text dtr-promobox-caption-text-on-hover">' + settings.promobox_text + '</div>';
				}
		
			html += '</div>';
		}
		html += '</div></div>';	
		print( html );
		#>
		<?php
	}
}