<?php
namespace BusybellaAddons\Widgets;

use Elementor\Widget_Base;
use Elementor\Controls_Manager;
use Elementor\Utils;

if ( ! defined( 'ABSPATH' ) ) {
	exit; // Exit if accessed directly.
}

/**
 * About Widget
 */
class Busybella_Quote extends Widget_Base {

	/**
	 * Retrieve widget name.
	 * @access public
	 * @return string Widget name.
	 */
	public function get_name() {
		return 'themequote';
	}

	/**
	 * Retrieve widget title.
	 * @access public
	 * @return string Widget title.
	 */
	public function get_title() {
		return __( 'Blockquote', 'busybella' );
	}

	/**
	 * Retrieve widget icon.
	 * @access public
	 * @return string Widget icon.
	 */
	public function get_icon() {
		return 'eicon-favorite';
	}

	/**
	 * Retrieve the list of categories widget belongs to.
	 * Used to determine where to display the widget in the editor.
	 * @access public
	 * @return array Widget categories.
	 */
	public function get_categories() {
		return array('dtr-element');
	}
	

	/**
	 * Register widget controls.
	 * Adds different input fields to allow the user to change and customize the widget settings.
	 * @access protected
	 */
	protected function _register_controls() {
		
		// content control starts
		$this->start_controls_section(
			'section_quote_content',
			[
				'label' => __( 'Content', 'busybella' ),
			]
		);

		// text
		$this->add_control(
			'quote_text',
			[
				'name' => 'tab_content',
				'label' => __( 'Quote Text', 'busybella' ),
				'type' => Controls_Manager::WYSIWYG,
				'default' => __( 'Quote Goes Here', 'busybella' ),
				'show_label' => true,
			]
		);
		
		// source
		$this->add_control(
			'quote_source',
			[
				'label' => __( 'Quote Source', 'busybella' ),
				'type' => Controls_Manager::TEXT,
				'default' => __( 'Source', 'busybella' ),
				'label_block' => true,
			]
		);
		
		$this->end_controls_section();
		// content control ends

		// style control starts
		$this->start_controls_section(
			'section_style_content',
			[
				'label' => __( 'Content', 'busybella' ),
				'tab'   => Controls_Manager::TAB_STYLE,
			]
		);

		$this->add_control(
			'quote_text_color',
			[
				'label' => __( 'Quote Text Color', 'busybella' ),
				'default' => '',
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .dtr-blockquote-wrapper .dtr-blockquote' => 'color: {{VALUE}};',
				],
			]
		);
		
		$this->add_control(
			'quote_source_color',
			[
				'label' => __( 'Quote Source Color', 'busybella' ),
				'default' => '',
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .dtr-blockquote-wrapper .dtr-quote-source' => 'color: {{VALUE}};',
				],
			]
		);
		
		$this->end_controls_section();
		// style control ends
		
	}

	/**
	 * Render widget output on the frontend.
	 * Written in PHP and used to generate the final HTML.
	 * @access protected
	 */
	protected function render() {
		$settings = $this->get_settings(); 
		$html = ''; 
		$html .= '<div class="dtr-blockquote-wrapper clearfix">';
		if ( ! empty( $settings['quote_text'] ) ) {
			$html .= sprintf( '<blockquote class="dtr-blockquote">%s</blockquote>', $settings['quote_text'] );
		}
		if ( ! empty( $settings['quote_source'] ) ) {
			$html .= sprintf( '<span class="dtr-quote-source">%s</span>', $settings['quote_source'] );
		}
		$html .= '</div>';
		echo $html;	
	}

	/**
	 * Render widget output in the editor.
	 * Written as a Backbone JavaScript template and used to generate the live preview.
	 * @access protected
	 */
	protected function _content_template() {
		?>
		<#
		var html = '<div class="dtr-blockquote-wrapper clearfix">';
		if ( settings.quote_text ) {
			html += '<blockquote class="dtr-blockquote">' + settings.quote_text + '</blockquote>';
		}
		if ( settings.quote_source ) {
			html += '<span class="dtr-quote-source">' + settings.quote_source + '</span>';
		}
		html += '</div>';
		print( html );
		#>
		<?php
	}
}